/*!
 * (C) Emu Analytics
 */
import { Component, Element, Event, Host, h, Prop, Method, Watch } from '@stencil/core';
import { randomId } from '../../utils/random-id';
import { formatEl, debugLifecycle } from '../../utils/debug';
import flatpickr from 'flatpickr';
import { createColorClasses } from '../../utils/theme';
import dayjs from 'dayjs';
import utc from 'dayjs/plugin/utc';
dayjs.extend(utc);
/**
 * @since 1.0
 * @status stable
 *
 */
export class FlowDateTimePicker {
  constructor() {
    /**
     * The date/time mode.
     */
    this.mode = 'date';
    /** Set to `true` to display a border. */
    this.border = true;
    /**
     * Set to `true` to open the date/time picker on mouse click.
     */
    this.openOnClick = true;
    /**
     * Set to `true` to enable seconds in the display.
     */
    this.enableSeconds = false;
    /**
     * @internal
     * Set to `true` to display as an inline element.
     */
    this.inline = false;
    /**
     * The display format for the selected date/time.
     */
    this.format = 'YYYY-MM-DD';
    /**
     * The minimum date/time that can be selected (ISO8601 string or Date object).
     */
    this.minDate = null;
    /**
     * The maximum date/time that can be selected (ISO8601 string or Date object).
     */
    this.maxDate = null;
    /**
     * Adjusts the step for the minute input.
     */
    this.minuteIncrement = 1;
    /**
     * The position of the popup date/time selector.
     */
    this.position = 'auto';
    /**
     * Set to `true` to enable static positioning of popup calendars. By default
     * calendars are positioned absolutely using body coordinates.
     */
    this.static = false;
    /**
     * Set to `true` to enable fixed positioning of popup calendars. By default
     * calendars are positioned absolutely using body coordinates.
     */
    this.fixed = false;
    /**
     * Specify 12 or 24 hour clock format.
     */
    this.clockMode = '24';
    /**
     * The value of the picker. ISO8601 string
     */
    this.value = null;
    /**
     * Set display mode to UTC (default is local time)
     */
    this.utc = false;
  }
  /** Open the date/time picker */
  async open() {
    this.picker.open();
  }
  /** Close the date/time picker */
  async close() {
    this.picker.close();
  }
  valueChanged(val) {
    var _a;
    val = (this.utc ? dayjs.utc(val) : dayjs(val)).format('YYYY-MM-DDTHH:mm:ss');
    (_a = this.picker) === null || _a === void 0 ? void 0 : _a.setDate(val, false);
  }
  async componentDidLoad() {
    if (!this.el.id) {
      this.el.setAttribute('id', randomId('datetime-picker'));
    }
    debugLifecycle(`${formatEl(this.el)} did load`);
    this.picker = flatpickr(this.inputEl, {
      appendTo: this.containerEl,
      static: this.static,
      altInput: true,
      altFormat: this.format,
      clickOpens: this.openOnClick,
      dateFormat: 'YYYY-MM-DDTHH:mm:ss',
      formatDate: (date, format, locale) => {
        const val = dayjs(date).format(format);
        return val;
      },
      parseDate: (date, format) => {
        const val = dayjs(date, format).toDate();
        return val;
      },
      enableTime: this.mode === 'time' || this.mode === 'datetime',
      enableSeconds: this.enableSeconds,
      inline: this.inline,
      maxDate: this.maxDate,
      minDate: this.minDate,
      minuteIncrement: this.minuteIncrement,
      noCalendar: this.mode === 'time',
      position: this.position,
      time_24hr: this.clockMode === '24',
      onChange: this.onDateTimeChanged.bind(this),
      onOpen: this.onDateTimeOpened.bind(this)
    });
    this.valueChanged(this.value);
  }
  async disconnectedCallback() {
    debugLifecycle(`${formatEl(this.el)} did unload`);
    this.picker.destroy();
    this.picker = null;
  }
  render() {
    const hostClasses = Object.assign({}, createColorClasses(this.color));
    const containerClasses = {
      container: true,
      border: this.border,
      fixed: this.fixed
    };
    return (h(Host, { class: hostClasses },
      h("div", { class: containerClasses, ref: el => (this.containerEl = el) },
        h("input", { ref: el => (this.inputEl = el), placeholder: this.placeholder }))));
  }
  onDateTimeChanged(selectedDates, dateStr, instance) {
    this.value = (this.utc ? dayjs.utc(dateStr) : dayjs(dateStr)).toISOString();
    this.flowChange.emit({ value: this.value == null ? this.value : this.value.toString() });
  }
  onDateTimeOpened() {
    this.flowDateTimeOpened.emit();
  }
  static get is() { return "flow-date-time-picker"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["date-time-picker.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["date-time-picker.css"]
  }; }
  static get properties() { return {
    "mode": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'date' | 'time' | 'datetime'",
        "resolved": "\"date\" | \"datetime\" | \"time\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The date/time mode."
      },
      "attribute": "mode",
      "reflect": false,
      "defaultValue": "'date'"
    },
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "PredefinedColor",
        "resolved": "\"danger\" | \"gray\" | \"primary\" | \"secondary\" | \"success\" | \"warning\"",
        "references": {
          "PredefinedColor": {
            "location": "import",
            "path": "../../utils/theme"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The accent color of the popup date/time selector. Colors are taken from the application palette."
      },
      "attribute": "color",
      "reflect": false
    },
    "border": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to display a border."
      },
      "attribute": "border",
      "reflect": false,
      "defaultValue": "true"
    },
    "openOnClick": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to open the date/time picker on mouse click."
      },
      "attribute": "open-on-click",
      "reflect": false,
      "defaultValue": "true"
    },
    "enableSeconds": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to enable seconds in the display."
      },
      "attribute": "enable-seconds",
      "reflect": false,
      "defaultValue": "false"
    },
    "inline": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": "Set to `true` to display as an inline element."
          }],
        "text": ""
      },
      "attribute": "inline",
      "reflect": false,
      "defaultValue": "false"
    },
    "format": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The display format for the selected date/time."
      },
      "attribute": "format",
      "reflect": false,
      "defaultValue": "'YYYY-MM-DD'"
    },
    "minDate": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | Date",
        "resolved": "Date | string",
        "references": {
          "Date": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The minimum date/time that can be selected (ISO8601 string or Date object)."
      },
      "attribute": "min-date",
      "reflect": false,
      "defaultValue": "null"
    },
    "maxDate": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | Date",
        "resolved": "Date | string",
        "references": {
          "Date": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The maximum date/time that can be selected (ISO8601 string or Date object)."
      },
      "attribute": "max-date",
      "reflect": false,
      "defaultValue": "null"
    },
    "minuteIncrement": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Adjusts the step for the minute input."
      },
      "attribute": "minute-increment",
      "reflect": false,
      "defaultValue": "1"
    },
    "position": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'above' | 'below' | 'auto'",
        "resolved": "\"above\" | \"auto\" | \"below\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The position of the popup date/time selector."
      },
      "attribute": "position",
      "reflect": false,
      "defaultValue": "'auto'"
    },
    "static": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to enable static positioning of popup calendars. By default\ncalendars are positioned absolutely using body coordinates."
      },
      "attribute": "static",
      "reflect": false,
      "defaultValue": "false"
    },
    "fixed": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set to `true` to enable fixed positioning of popup calendars. By default\ncalendars are positioned absolutely using body coordinates."
      },
      "attribute": "fixed",
      "reflect": false,
      "defaultValue": "false"
    },
    "clockMode": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'12' | '24'",
        "resolved": "\"12\" | \"24\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specify 12 or 24 hour clock format."
      },
      "attribute": "clock-mode",
      "reflect": false,
      "defaultValue": "'24'"
    },
    "placeholder": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The input placeholder."
      },
      "attribute": "placeholder",
      "reflect": false
    },
    "value": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string | undefined | null",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The value of the picker. ISO8601 string"
      },
      "attribute": "value",
      "reflect": true,
      "defaultValue": "null"
    },
    "utc": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set display mode to UTC (default is local time)"
      },
      "attribute": "utc",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get events() { return [{
      "method": "flowChange",
      "name": "flowChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the selected date/time is changed by user interaction."
      },
      "complexType": {
        "original": "DateTimePickerChangeEventDetail",
        "resolved": "DateTimePickerChangeEventDetail",
        "references": {
          "DateTimePickerChangeEventDetail": {
            "location": "import",
            "path": "./interface"
          }
        }
      }
    }, {
      "method": "flowDateTimeOpened",
      "name": "flowDateTimeOpened",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the popup date/time selector is opened."
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "open": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Open the date/time picker",
        "tags": []
      }
    },
    "close": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Close the date/time picker",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "value",
      "methodName": "valueChanged"
    }]; }
}
