/*!
 * (C) Emu Analytics
 */
import { t as toJS, v as debugMapStyle, k as remove, o as observable, e as computed, f as action, w as keys } from './debug.js';
import { c as computedFn, M as MaplibreGLSpecHelper } from './maplibre-spec-helper.js';
import { P as ParseError } from './parse-error.js';
import { E as ERRORS } from './constants.js';

/**
 * @internal
 */
class ValidationError extends Error {
  constructor(message, source, errors) {
    super(ValidationError.formatMessage(message, source, errors));
    this.name = ERRORS.ValidationError;
    this.source = source;
    this.errors = errors;
  }
  static formatMessage(message, _source, errors) {
    return [message].concat(errors).join('\n');
  }
}

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
};
/**
 * Core functionality for Flo.w map layers. Wrapped by the `<flow-map-layer>` web component.
 *
 * @noInheritDoc
 */
class FlowCoreMapLayer {
  /**
   * Constructs a new `FlowCoreMapLayer` instance.
   *
   * @param options Map layer options.
   */
  constructor(options) {
    this.minZoom = 0;
    this.maxZoom = 18;
    this.parsedStyle = {};
    /**
     * Computed function to collect layer properties from the parsed style base on type 'paint' or 'layout'
     * Also calls expandLayerProperty on each property to expand state variables etc.
     *
     */
    this.collectLayerProperties = computedFn(function collectLayerProperties(propertyType) {
      const props = keys(this.parsedStyle)
        .filter((propertyKey) => MaplibreGLSpecHelper.instance.getPropertyType(propertyKey, this.options.type) === propertyType)
        .reduce((acc, propertyKey) => {
        acc[propertyKey] = this.expandLayerProperty(propertyKey);
        return acc;
      }, {});
      return Object.keys(props).length ? props : null;
    }, { name: 'collectLayersProperties' });
    /**
     * Computed function to retrieve expanded property expression from parsed style.
     *
     * 'Expansion' includes:
     *    - replacing state variables
     *    - converting visibility form boolean expression to 'none'/'visible' string literal
     *
     */
    this.expandLayerProperty = computedFn(function expandLayerProperty(propertyKey) {
      // Clone and return plain non-observable property
      let property = toJS(this.parsedStyle[propertyKey].expr, { detectCycles: false });
      property = this.options.flowMap.context.parser.expandReactiveExpression(property);
      // Visibility is treated as a boolean property but needs to be converted to string property
      // for maplibre to handle. State variables have already been expanded above so any state changes
      // will re-trigger computing the visibility property.
      if (propertyKey === 'visibility') {
        try {
          property = MaplibreGLSpecHelper.instance.evaluateExpression(property) ? 'visible' : 'none';
        }
        catch (e) {
          this.options.flowMap.context.emitError(e);
        }
      }
      return property;
    });
    this.id = options.id;
    this.options = Object.assign({ minZoom: 0, maxZoom: 18 }, options);
    this.minZoom = this.options.minZoom;
    this.maxZoom = this.options.maxZoom;
  }
  /**
   * Get computed MaplibreGL style specification for this layer.
   *
   * <flow-badge pill>Reactive</flow-badge>
   */
  get maplibreLayerDef() {
    const layer = {
      id: this.options.id
    };
    if (typeof this.minZoom !== 'undefined') {
      layer.minzoom = this.minZoom;
    }
    if (typeof this.maxZoom !== 'undefined') {
      layer.maxzoom = this.maxZoom;
    }
    if (this.options.type) {
      layer.type = this.options.type;
    }
    if (this.options.source) {
      layer.source = this.options.source;
    }
    if (this.options.sourceLayer) {
      layer['source-layer'] = this.options.sourceLayer;
    }
    const paintProps = this.collectLayerProperties('paint');
    const layoutProps = this.collectLayerProperties('layout');
    if (this.parsedFilter) {
      layer.filter = this.options.flowMap.context.parser.expandReactiveExpression(toJS(this.parsedFilter));
    }
    if (paintProps) {
      layer.paint = paintProps;
    }
    if (layoutProps) {
      layer.layout = layoutProps;
    }
    return layer;
  }
  /**
   * Set the layer style.
   *
   * @param style Style as a Flo.w layer style specification string.
   */
  setStyle(style) {
    style = style || '';
    const parseResult = this.options.flowMap.context.parser.parseProgram(style);
    if (parseResult.status) {
      // Validated all style properties and collect errors
      const errors = Object.keys(parseResult.value).reduce((acc, prop) => {
        const errs = this.validateParsedProperty(prop, parseResult.value[prop]);
        if (errs) {
          acc = acc.concat(errs);
        }
        return acc;
      }, []);
      if (errors && errors.length) {
        this.options.flowMap.context.emitError(new ValidationError('Validation errors in style:', style, errors));
      }
      const parsedStyle = Object.keys(parseResult.value).reduce((acc, prop) => {
        acc[prop] = parseResult.value[prop];
        return acc;
      }, {});
      this.parsedStyle = parsedStyle;
    }
    else {
      this.options.flowMap.context.emitError(new ParseError(style, parseResult));
    }
  }
  /**
   * Set an individual style property.
   *
   * @param property Property name.
   * @param value Property style expression.
   */
  setStyleProperty(property, value) {
    debugMapStyle('setting style property', property, value);
    const errors = this.validateParsedProperty(property, { expr: value, index: null });
    if (errors && errors.length) {
      this.options.flowMap.context.emitError(new ValidationError(`Validation error:`, property, errors));
      return;
    }
    if (value === null) {
      // Remove property
      remove(this.parsedStyle, property);
      return;
    }
    const parseResult = this.options.flowMap.context.parser.parseExpression(value);
    if (!parseResult.status) {
      this.options.flowMap.context.emitError(new ParseError(value, parseResult));
      return;
    }
    else {
      this.parsedStyle[property] = { expr: parseResult.value, index: null };
    }
  }
  /**
   * Set the layer filter.
   *
   * @param filter Layer filter expression.
   */
  setFilter(filter) {
    const errors = this.validateFilter(filter);
    if (errors && errors.length) {
      this.options.flowMap.context.emitError(new ValidationError('Validaton error in filter:', filter, errors));
      return;
    }
    if (!filter) {
      // Remove property
      this.parsedFilter = null;
      return;
    }
    const parseResult = this.options.flowMap.context.parser.parseExpression(filter);
    if (!parseResult.status) {
      this.options.flowMap.context.emitError(new ParseError(filter, parseResult));
      return;
    }
    else {
      this.parsedFilter = parseResult.value;
    }
  }
  /**
   * Set multiple layer style properties in a single transaction.
   *
   * @param properties Property name/value pairs.
   */
  setStyleProperties(properties) {
    Object.keys(properties).forEach(p => this.setStyleProperty(p, properties[p]));
  }
  setInteractive(interactive = true) {
    this.options.interactive = interactive;
  }
  /**
   * Validate parsed property expression. Returns errors as an array of error messages.
   *
   */
  validateParsedProperty(prop, expr) {
    const errors = [];
    const metadata = MaplibreGLSpecHelper.instance.getPropertyMetadata(prop, this.options.type);
    if (!metadata) {
      const index = (expr.index && ` at line ${expr.index.line}, column ${expr.index.column}`) || '';
      errors.push(`Unrecognized layer property '${prop}'${index}`);
    }
    return errors;
  }
  validateFilter(_filter) {
    const errors = [];
    // TODO
    return errors;
  }
}
__decorate([
  observable
], FlowCoreMapLayer.prototype, "minZoom", void 0);
__decorate([
  observable
], FlowCoreMapLayer.prototype, "maxZoom", void 0);
__decorate([
  observable
], FlowCoreMapLayer.prototype, "parsedStyle", void 0);
__decorate([
  observable
], FlowCoreMapLayer.prototype, "parsedFilter", void 0);
__decorate([
  computed
], FlowCoreMapLayer.prototype, "maplibreLayerDef", null);
__decorate([
  action
], FlowCoreMapLayer.prototype, "setStyle", null);
__decorate([
  action
], FlowCoreMapLayer.prototype, "setStyleProperty", null);
__decorate([
  action
], FlowCoreMapLayer.prototype, "setFilter", null);
__decorate([
  action
], FlowCoreMapLayer.prototype, "setStyleProperties", null);

export { FlowCoreMapLayer as F };
