import { FlowCoreMap } from './flow-core-map';
import { LayerType } from '../maplibre-spec-helper';
/**
 * [[FlowCoreMapLayer]] options.
 */
export interface FlowCoreMapLayerOptions {
  /** Layer ID. */
  id: string;
  /** Layer type. */
  type: LayerType;
  /** Parent map. */
  flowMap: FlowCoreMap;
  /** Map data source to display. */
  source?: string;
  /** Map data source layer to display. (Applicable to 'vector'-type data sources). */
  sourceLayer?: string;
  /** Enable feature hover effect and click handling. */
  interactive?: boolean;
  /** Insert the layer below specified layer. */
  below?: string;
  /** Insert the layer above specified layer. */
  above?: string;
  /** Minimum visible zoom level. */
  minZoom?: number;
  /** Maximum visible zoom level. */
  maxZoom?: number;
}
/**
 * Map layer style property set.
 */
interface MapLayerStyleProperties {
  [propertyKey: string]: string;
}
/**
 * Core functionality for Flo.w map layers. Wrapped by the `<flow-map-layer>` web component.
 *
 * @noInheritDoc
 */
export declare class FlowCoreMapLayer {
  minZoom: number;
  maxZoom: number;
  private parsedStyle;
  private parsedFilter;
  id: string;
  readonly options: FlowCoreMapLayerOptions;
  /**
   * Constructs a new `FlowCoreMapLayer` instance.
   *
   * @param options Map layer options.
   */
  constructor(options: FlowCoreMapLayerOptions);
  /**
   * Get computed MaplibreGL style specification for this layer.
   *
   * <flow-badge pill>Reactive</flow-badge>
   */
  get maplibreLayerDef(): any;
  /**
   * Set the layer style.
   *
   * @param style Style as a Flo.w layer style specification string.
   */
  setStyle(style: string): void;
  /**
   * Set an individual style property.
   *
   * @param property Property name.
   * @param value Property style expression.
   */
  setStyleProperty(property: string, value: string): void;
  /**
   * Set the layer filter.
   *
   * @param filter Layer filter expression.
   */
  setFilter(filter: string): void;
  /**
   * Set multiple layer style properties in a single transaction.
   *
   * @param properties Property name/value pairs.
   */
  setStyleProperties(properties: MapLayerStyleProperties): void;
  setInteractive(interactive?: boolean): void;
  /**
   * Validate parsed property expression. Returns errors as an array of error messages.
   *
   */
  private validateParsedProperty;
  private validateFilter;
  /**
   * Computed function to collect layer properties from the parsed style base on type 'paint' or 'layout'
   * Also calls expandLayerProperty on each property to expand state variables etc.
   *
   */
  private collectLayerProperties;
  /**
   * Computed function to retrieve expanded property expression from parsed style.
   *
   * 'Expansion' includes:
   *    - replacing state variables
   *    - converting visibility form boolean expression to 'none'/'visible' string literal
   *
   */
  private expandLayerProperty;
}
export {};
